#include "DeerStudio/EditorEngine.h"
#include "DeerStudio/EditorEngine/ErrorHandle.h"
#include "DeerStudio/EditorEngine/API.h"

#include "scripthandle.h"
#include "scriptany.h"
#include "angelscript.h"

namespace Deer {
    void EditorEngine::registerUIFunctions() {
        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "void textColor(float, float, float, const string& in)",
            asFUNCTION(textColor),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "void text(const string& in)",
            asFUNCTION(text),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "void textCenter(const string& in)",
            asFUNCTION(textCenter),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "void textEnd(const string& in)",
            asFUNCTION(textEnd),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "void drawIcon(const string& in, int)",
            asFUNCTION(drawIcon),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "void drawFrameBuffer(FrameBuffer, int, int)",
            asFUNCTION(drawFrameBuffer),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "void drawFrameBufferCentered(FrameBuffer, int, int)",
            asFUNCTION(drawFrameBufferCentered),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "bool isItemClicked(int)",
            asFUNCTION(
                isItemClicked
            ),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "bool isMouseDoubleClicked(int)",
            asFUNCTION(
                isMouseDoubleClicked
            ),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "void drawIconCentered(const string& in, int)",
            asFUNCTION(drawIconCentered),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "void space()",
            asFUNCTION(space),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "void space(int, int = 10)",
            asFUNCTION(space_params),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "bool menuItem(const string& in)",
            asFUNCTION(menuItem),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "void menuSpace(const string& in, any@+, ReciverFunc@+)",
            asFUNCTION(menuSpace),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "void menuItemDisabled(const string& in)",
            asFUNCTION(menuItemDisabled),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "bool button(const string& in)",
            asFUNCTION(button),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "bool buttonCenter(const string&in)",
            asFUNCTION(buttonCenter),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "bool buttonEnd(const string&in)",
            asFUNCTION(buttonEnd),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "bool inputText(const string& in, const string& in, string& out)",
            asFUNCTION(inputText),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "bool checkbox(const string& in, bool)",
            asFUNCTION(checkbox),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "bool checkboxDisabled(const string& in, bool)",
            asFUNCTION(checkboxDisabled),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "float magicSlider(const string& in, float, float)",
            asFUNCTION(magicSlider),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "vec3 magicSlider3(const string& in, vec3, float)",
            asFUNCTION(magicSlider3),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "void sameline()",
            asFUNCTION(sameline),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "void separator()",
            asFUNCTION(separator),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "void title(const string&in)",
            asFUNCTION(title),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "void titleEnd(const string&in)",
            asFUNCTION(titleEnd),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "void titleCenter(const string&in)",
            asFUNCTION(titleCenter),
            asCALL_CDECL
        ));

        AS_CHECK(scriptEngine->RegisterGlobalFunction(
            "void titleCenterY(const string&in, int)",
            asFUNCTION(titleCenterY),
            asCALL_CDECL
        ));
    }
}